#! /bin/sh
#----------------------------------------------------------------------------
# /usr/local/bin/monitoring.sh  - Monitoring shell
#
# Creation:     18.10.2005  Stephan Sanders
# Last Update:  13.04.2019  Stephan Sanders
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------
# set -x

# config einlesen
. /etc/config.d/monitoring

if [ -f /etc/config.d/eistemp ]
then
. /etc/config.d/eistemp
fi

. /var/install/include/eislib

# Flag-ueberpruefung
flagnew="/var/run/monitoring-flag.new"
flagold="/var/run/monitoring-flag.old"

# Ueberpruefe ob Monitoring aktiviert werden soll?

if [ "$START_MONITORING" = "yes" ] 
then
    if [ -f "$flagold" ]
    then
#    echo "FLAGOLD Variablen werden aufgenommen"
    . $flagold
#    else
#    echo "Achtung FLAGOLD existiert nicht!"
    fi

    echo "# Monitoring-Status" > $flagnew
 
    # nun die Gruppenschleife!
    idx=1
    while [ "$idx" -le "$MONITORING_GROUP_N" ]
    do
        # Gruppe aktiv?
        eval groupact='$MONITORING_GROUP_'$idx'_ACTIVE'
        if [ "$groupact" == "yes" ]
        then
            flag="0"
            alarm="0"
            notify="0"
            rm -f /var/log/monitoring.alarm.txt
            rm -f /var/log/monitoring.sms.alarm.txt

            # Sourceschleife (in der Gruppenschleife)
            idxs=1
            eval sourcenr='$MONITORING_GROUP_'$idx'_SOURCE_N'
            while [ "$idxs" -le "$sourcenr" ]
            do
                # Variablen auslesen fuer jede Quelle
                eval type='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_TYPE'
                eval name='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_NAME'
                eval runcmd='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_CMD'
                eval unit='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_UNIT'
                eval min='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                eval max='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_MAX'

                #-----------------------------------------------------------
                # Typenabfrage Beginn Eistemp
                #-----------------------------------------------------------
                if [ "$type" == "eistemp" ]
                then
                    if [ `/var/install/bin/check-version eistemp 0.4.0` = "new" ]
                    then
                        value=`cut -d',' -f1 /usr/local/eistemp/eistemp$name`
                    else
                        value=`cut -d',' -f1 /var/eistemp/eistemp$name`
                    fi
                    if [ "$max" != "" ]
                    then
                        if   [ "$value" = "" ]
                        then
                            value="999"
                        fi
                        if  [ "$value" -gt "$max" ]
                        then
                            # realname=`cat /usr/local/eistemp/eistempname$name`
                            eval realname='$EISTEMP_SENSOR_'$name'_NAME'
                            echo "Der Temperatur-Sensor $realname misst aktuell: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max$unit und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Temp-Sensor: $realname $value GradC. Max: $max GradC.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"

                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if   [ "$value" = "" ]
                        then
                            value="999"
                        fi
                        if  [ "$value" -lt "$min" ]
                        then
                            # realname=`cat /usr/local/eistemp/eistempname$name`
                            eval realname='$EISTEMP_SENSOR_'$name'_NAME'
                            echo "Der Temperatur-Sensor $realname misst aktuell: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min$unit und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Temp-Sensor: $realname $value GradC. Min: $min GradC.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # eistemp typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Beginn ping
                #-----------------------------------------------------------
                if [ "$type" == "ping" ]
                then
                    value=`ping -c $max $name 2>/dev/null | grep "packets" | sed 's/.* transmitted, //; s/received.*//; s/unknown host '$name'/0/'`
                    if  [ "$value" -lt "$min" ]
                    then
                        echo "$name ist nicht per ICMP erreichbar!">> /var/log/monitoring.alarm.txt
                        echo "$max transmitted, $value received!">> /var/log/monitoring.alarm.txt
                        echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                        echo -n "$name ist nicht per ICMP erreichbar.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # ping typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Beginn ping6
                #-----------------------------------------------------------
                if [ "$type" == "ping6" ]
                then
                    value=`ping6 -c $max $name 2>/dev/null | grep "received" | sed 's/.* transmitted, //; s/received.*//; s/unknown host '$name'/0/'`
                    if  [ "$value" -lt "$min" ]
                    then
                        echo "$name ist nicht per ICMP erreichbar!">> /var/log/monitoring.alarm.txt
                        echo "$max transmitted, $value received!">> /var/log/monitoring.alarm.txt
                        echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                        echo -n "$name ist nicht per ICMP erreichbar.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # ping6 typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Typenabfrage Beginn loadavg
                #-----------------------------------------------------------
                if [ "$type" == "loadavg" ]
                then
                    value=`cut -d " " -f$name /proc/loadavg  | sed "s/\\.//; s/^0*//" 2>/dev/null`
                    if [ "$max" != "" ]
                    then
                        if  [ "$value" -gt "$max" ]
                        then
                            case $name in
                                1) realname="1min";;
                                2) realname="5min";;
                                3) realname="10min";;
                            esac
                            echo "Loadavg $realname liegt aktuell bei: $value%.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max% und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Loadavg: $realname $value%. Max: $max%.%0D%0A">> /var/log/monitoring.sms.alarm.txt    
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if  [ "$value" -lt "$min" ]
                        then
                            case $name in
                                1) realname="1min";;
                                2) realname="5min";;
                                3) realname="10min";;
                            esac
                            echo "Loadavg $realname liegt aktuell bei: $value%.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min% und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "-----------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Loadavg: $realname $value%. Min: $min%.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # loadavg typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Typenabfrage Beginn lmsensors
                #-----------------------------------------------------------
                if [ "$type" == "lmsensors" ]
                then
                    #if [ "$1" = "debug" ]; then set -x; fi    
                    value=`/usr/bin/sensors 2>/dev/null | grep "$name" | awk -F ":" '{ print $2 }' | awk '{ print $1 }' | sed s"/[+-]//" | sed s"/ (.*$//; s/ .*$//" | cut -d "." -f1 | sed s'/.C$//'`
                    if [ "$max" != "" ]
                    then
                        if  [ "$value" -gt "$max" ]
                        then
                            echo "Der Wert von lmsensors $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max$unit und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "lmsens: $name $value$unit. Max: $max$unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt    
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$1" = "debug-lms" ]
                        then
                            echo "sensors $name + val: $value"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if  [ "$value" -lt "$min" ]
                        then
                            echo "Der Wert von lmsensors $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min$unit und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "lmsens: $name $value$unit. Min: $min$unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt	
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$1" = "debug-lms" ]
                        then
                            echo "sensors $name - val: $value"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                    #if [ "$1" = "debug" ]; then set +x; fi
                fi
                #-----------------------------------------------------------
                # lmsensors typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # http Echoping typ begin
                #-----------------------------------------------------------
                if [ "$type" == "echoping" ]
                then
                    type="http"
                fi
                if [ "$type" == "http" ]
                then
                    value=`/usr/local/bin/echoping -t2 -h / $name 2>/dev/null | cut -c 1-7 `
                    if  [ "$value" != "Elapsed" ]
                    then
                        echo "$name ist nicht per http erreichbar!" >> /var/log/monitoring.alarm.txt
                        echo -n "$name ist nicht per http erreichbar.%0D%0A" >> /var/log/monitoring.sms.alarm.txt    
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # http typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # pop3test typ begin
                #-----------------------------------------------------------
                if [ "$type" == "pop3" ]
                then
                    value=`( echo "quit" ) | telnet $name 110 | sed -n '4p' | cut -c0-3 2>/dev/null`
                    if  [ "$value" != "+OK" ]
                    then
                        echo "pop3 auf $name ist nicht erreichbar!" >> /var/log/monitoring.alarm.txt
                        echo -n "pop3 auf $name ist nicht erreichbar.%0D%0A" >> /var/log/monitoring.sms.alarm.txt
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # pop3test typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # smtp-neu typ begin!
                #-----------------------------------------------------------
                if [ "$type" == "smtp" ]
                then
                    value=`/usr/local/bin/echoping -S $name 2>/dev/null | cut -c 1-7`
                    if  [ "$value" != "Elapsed" ]
                    then
                        echo "SMTP auf $name ist nicht erreichbar!" >> /var/log/monitoring.alarm.txt
                        echo -n "SMTP auf $name ist nicht erreichbar.%0D%0A" >> /var/log/monitoring.sms.alarm.txt    
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # smtp-neu typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # ftptest typ begin
                #-----------------------------------------------------------
                if [ "$type" == "ftp" ]
                then
                    value=`( echo "QUIT" ) | netcat -i 1 $name 21 | sed -n '1p' | cut -c0-3 2>/dev/null`
                    if  [ "$value" != "220" ]
                    then
                        echo "FTP auf $name ist nicht erreichbar!" >> /var/log/monitoring.alarm.txt
                        echo -n "FTP auf $name ist nicht erreichbar.%0D%0A" >> /var/log/monitoring.sms.alarm.txt
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # ftptest typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Beginn Typ Cmd
                #-----------------------------------------------------------
                if [ "$type" == "cmd" ]
                then
                    value=`$runcmd 2>/dev/null`
                    if [ "$max" != "" ]
                    then
                        if  [ "$value" -gt "$max" ]
                        then
                            echo "$name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max$unit und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "$name: $value$unit. Max: $max$unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt    
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if  [ "$value" -lt "$min" ]
                        then
                            echo "$name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min$unit und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "$name: $value$unit. Min: $min$unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt	
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # Ende von Typ CMD
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Typenabfrage Beginn hddtemp
                #-----------------------------------------------------------
                if [ "$type" == "hddtemp" ]
                then
                    value=`hddtemp -n $name  2>/dev/null | sed s'/^.* drive is sleeping/0/'`
                    if [ "$max" != "" ]
                    then
                        if  [ "$value" -gt "$max" ]
                        then
                            echo "Die Temperatur von $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max$unit und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Temperatur: $name $value GradC. Max: $max GradC.%0D%0A">> /var/log/monitoring.sms.alarm.txt    
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if  [ "$value" -lt "$min" ]
                        then
                            echo "Die Temperatur von $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min$unit und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "-----------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Temperatur: $name $value GradC Min: $min GradC.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # hddtemp typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # ps typ begin
                #-----------------------------------------------------------
                if [ "$type" == "ps" ]
                then
                    value=`ps ax | grep "$name" | grep -v "grep" 2>/dev/null`
                    if [ "$value" == "" ] 
                    then
                        echo "Prozess $name laeuft nicht!" >> /var/log/monitoring.alarm.txt
                        echo -n "Prozess $name laueft nicht.%0D%0A" >> /var/log/monitoring.sms.alarm.txt
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # ps typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Typenabfrage Beginn df
                #-----------------------------------------------------------
                if [ "$type" == "df" ]
                then
                    if [ "$min" != "" ]
                    then
                        value=`df -m | grep "$name" | awk '{ print $4 }' 2>/dev/null`
                        if  [ "$value" -lt "$min" ]
                        then
                            echo "Der Platz auf $name liegt aktuell bei: $value MB.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min MB und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "-----------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "Freier Platz: $name $value MB Min: $min MB.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # df typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # https echoping typ begin
                #-----------------------------------------------------------
                if [ "$type" == "https" ]
                then
                    value=`/usr/local/bin/echoping -t2 -C -h / $name 2>/dev/null | cut -c 1-7`
                    if  [ "$value" != "Elapsed" ]
                    then
                        echo "$name ist nicht per https erreichbar!" >> /var/log/monitoring.alarm.txt
                        echo -n "$name ist nicht per https erreichbar.%0D%0A" >> /var/log/monitoring.sms.alarm.txt    
                        echo "------------------------------------------------------" >> /var/log/monitoring.alarm.txt
                        alarm="1"
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                        flagvaluenow="1"
                    else
                        echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                        flagvaluenow="0"
                    fi
                    eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                    if [ "$1" = "debug" ]
                    then
                        echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                    fi
                    if [ "$flagvalueold" != "$flagvaluenow" ]
                    then
                        flag="1"
                    fi
                fi
                #-----------------------------------------------------------
                # https echoping typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Typenabfrage Beginn apcups
                #-----------------------------------------------------------
                if [ "$type" == "apcups" ]
                then
                    value=`cat /etc/apcupsd/apcupsd.status 2>/dev/null | grep "^$name" | awk '{ print $3 }' | cut -d"." -f1`
                    if [ "$max" != "" ]
                    then
                        if  [ "$value" -gt "$max" ]
                        then
                            echo "Der APC-UPS-Wert von $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der maximale Grenzwert betraegt $max$unit und ist somit ueberschritten!">> /var/log/monitoring.alarm.txt
                            echo "------------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "APC-UPS: $name $value $unit. Max: $max $unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt    
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MAX='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi

                    if [ "$min" != "" ]
                    then
                        if  [ "$value" -lt "$min" ]
                        then
                            echo "Der APC-UPS Wert von $name liegt aktuell bei: $value$unit.">> /var/log/monitoring.alarm.txt
                            echo "Der minimale Grenzwert betraegt $min$unit und ist somit unterschritten!">> /var/log/monitoring.alarm.txt
                            echo "-----------------------------------------------------">> /var/log/monitoring.alarm.txt
                            echo -n "APC-UPS: $name $value $unit. Min: $min $unit.%0D%0A">> /var/log/monitoring.sms.alarm.txt
                            alarm="1"
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='1'" >> $flagnew
                            flagvaluenow="1"
                        else
                            echo "GROUP_$idx""_SOURCE_$idxs""_MIN='0'" >> $flagnew
                            flagvaluenow="0"
                        fi
                        eval flagvalueold='$GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                        if [ "$1" = "debug" ]
                        then
                            echo "G$idx S$idxs $flagvalueold OLD<>NOW $flagvaluenow"
                        fi
                        if [ "$flagvalueold" != "$flagvaluenow" ]
                        then
                            flag="1"
                        fi
                    fi
                fi
                #-----------------------------------------------------------
                # apcups typ if ende
                #-----------------------------------------------------------

                #-----------------------------------------------------------
                # Hier koennen weitere Typen eingefuegt werden.
                #-----------------------------------------------------------

                #------------------------------------------------------------------------
                # SourceSchleife abschliessen
                idxs=`/usr/bin/expr $idxs + 1`
            done

            # Queries abgeschlossen. alarm?
            # echo "Flag: $flag Alarm: $alarm"
            # Flagcontrol benutzen ?
            if [ "$MONITORING_FLAGCONTROL" = "no" ]
            then
                if [ "$1" = "debug" ]
                then
                    mecho --warn "Flagcontrol is disabled"
                fi
                if [ "$flag" == "1" ]
                then
                    notify="1"
                fi
                if [ "$alarm" == "1" ]
                then
                    notify="1"
                fi
            else
                if [ "$1" = "debug" ]
                then
                    mecho --warn "Flagcontrol is enabled"
                fi
                if [ "$flag" == "1" ]
                then
                    notify="1"
                fi
            fi

            # Nur alarm melden wenn
            if [ "$1" = "debug" ]
            then
                echo "Notify ist $notify"
            fi
            if [ "$notify" == "1" ]
            then
                if [ "$1" = "config" ]
                then
                    if [ "$alarm" = "1" ]
                    then
                        mecho --error "Achtung Alarm vorhanden! Bitte die Config ueberpruefen!"
                    fi
                fi
                if [ "$1" = "debug" ]
                then
                    echo "Flag ist 1 Alarm=$alarm"
                fi
                if [ "$1" = "debug" ]
                then
                    echo "======================="
                fi

                #echo "Flag: $flag"
                #echo "Alarm: $alarm"
                if [ "$1" != "config" ]
                then
                    # Entwarnung?
                    if [ "$alarm" == "0" ]
                    then
                        subjectsuffix=" Entwarnung"
                    else
                        subjectsuffix=""
                    fi

                    # hole dir die Daten fuer benachrichtigungen
                    eval mail='$MONITORING_GROUP_'$idx'_MAIL'
                    eval yaps='$MONITORING_GROUP_'$idx'_YAPS'
                    eval subject='$MONITORING_GROUP_'$idx'_MAILSUBJECT'
                    if [ "$subject" == "" ]
                    then
                        subject="Monitoring and Report Tool"
                    fi
                    if [ "$mail" != "" ]
                    then
                        # nun die email vorbereiten
                        header=`cat /var/lib/monitoring/monitoring.header`
                        alarm=`cat /var/log/monitoring.alarm.txt 2>/dev/null`
                        if [ "$alarm" == "" ]
                        then
                            alarm="Es steht kein Alarm (mehr) an!"
                        fi
                        echo "$header" > /var/log/monitoring.alarm.txt
                        echo "$alarm" >> /var/log/monitoring.alarm.txt
                        footer=`cat /var/lib/monitoring/monitoring.footer`
                        echo "$footer" >> /var/log/monitoring.alarm.txt
                        mail -s "$subject $subjectsuffix" "$mail"</var/log/monitoring.alarm.txt
                    fi

                    if [ "$yaps" != "" ]
                    then
                        # nun die sms via yaps vorbereiten
                        alarmsms=`cat /var/log/monitoring.sms.alarm.txt 2>/dev/null`
                        if [ "$alarmsms" == "" ]
                        then
                            alarmsms="Es steht kein Alarm (mehr) an."
                        fi
                        yaps -v -f $yaps "$subject $subjectsuffix: $alarmsms" 
                    fi

                    # Deaktiviert fuer FLAG!
                    # else
                    # Wenn kein Alarm da ist!
                    # Ende if alarm
                    # fi
                else
                    echo "Config run! Report inactive!"
                    # Ende if fuer config
                fi
            else
                if [ "$1" = "debug" ]
                then
                    echo "Flag ist 0"
                    echo "======================"
                fi
                # Ende if fuer notify
            fi

            eval cmd='$MONITORING_GROUP_'$idx'_CMD'
            if [ "$cmd" != "" ]
            then

                if [ "$alarm" == "1" ]
                then
                    # nicht bei Entwarnung ausfuehren
                    # nun CMD ausfuehren"
                    $cmd 2>/dev/null
                fi
            fi

            # Wenn Gruppe nicht aktiv ist...
            # else
            # echo "Group$idx ignored"
        fi

        # GruppenSchleife abschliessen
        idx=`/usr/bin/expr $idx + 1`
    done

    if [ -f "$flagnew" ]
    then
        # echo "loesche FLAGOLD und NEW --> OLD"
        rm -r -f $flagold
        mv $flagnew $flagold
    fi

    # /usr/local/bin/monitoring2apache.sh
    # Abschluss Schleife "Start monitoring"
else
    mecho --info "Monitoring wurde nicht gestartet weil START_MONITORING=no"
fi