#!/bin/sh
#----------------------------------------------------------------------------
# /usr/local/htdocs/monitoring.cgi  - MiniHTTPd Output for Monitoring
#
# Creation:     19.10.2005  Stephan Sanders
# Last Update:  13.04.2019  Stephan Sanders
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

if [ "$QUERY_STRING" = "runmonitoring" ]
then
    /usr/local/bin/monitoring.sh &
#    echo "Location: monitoring.cgi"
#    echo ""
fi

echo 'Content-Type: text/html; charset=iso-8859-1'
echo "Cache-control: no-store" # HTTP/1.1 (or no-cache?)
echo "Pragma: no-cache"        # HTTP/1.0
echo Expires: `date -Ru`       # Expires now!
echo
echo
echo "<html><head><title>Monitoring & Report Tool</title>"
echo "<body bgcolor=#FFFFFF text=#000000 link=#0000FF vlink=#0000FF><font face=Arial>"
echo "<h2><center>Monitoring & Report Tool</h2>"

. /var/install/include/eislib
. /etc/config.d/monitoring

mecho --html --info "Monitoring & Report - Actual Data<br>"
mecho --html "---------------------------------------------------<br>"
if [ $START_MONITORING == "yes" ]
then
    # nun die Gruppenschleife!
    idx=1
    while [ "$idx" -le "$MONITORING_GROUP_N" ]
    do
        # Gruppe aktiv?
        eval groupact='$MONITORING_GROUP_'$idx'_ACTIVE'
        if [ "$groupact" == "yes" ]
        then
            mecho --html "Monitoring-Group$idx Status: active<br>"
            eval mail='$MONITORING_GROUP_'$idx'_MAIL'
            eval yaps='$MONITORING_GROUP_'$idx'_YAPS'
            if [ "$mail" = "" ] 
            then 
                mail="not set" 
            fi
            if [ "$yaps" = "" ] 
            then 
                yaps="not set" 
            fi

            echo "Notify Mail: $mail; YAPS: $yaps"
            echo ""
            mecho --html ""

            techo --html begin 10 20 9 9 9
            techo --html row 'Type'  Name  'Now ' 'Min' 'Max'

            # Sourceschleife (in der Gruppenschleife)
            idxs=1
            eval sourcenr='$MONITORING_GROUP_'$idx'_SOURCE_N'
            while [ "$idxs" -le "$sourcenr" ]
            do
                # Variablen auslesen fuer jede Quelle
                eval type='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_TYPE'
                eval name='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_NAME'
                eval unit='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_UNIT'
                eval min='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_MIN'
                eval max='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_MAX'
                eval runcmd='$MONITORING_GROUP_'$idx'_SOURCE_'$idxs'_CMD'
                if [ "$min" == "" ]
                then
                    min="-"
                fi
                if [ "$max" == "" ]
                then
                    max="-"
                fi

                # Definition eistemp
                if [ "$type" == "eistemp" ]
                then
                    value=`cut -d',' -f1 /var/eistemp/eistemp$name 2>/dev/null`
                    if [ "$value" = "" ]
                    then
                        value=`cut -d',' -f1 /usr/local/eistemp/eistemp$name 2>/dev/null`
                    fi
                    . /etc/config.d/eistemp
                    eval realname='$EISTEMP_SENSOR_'$name'_NAME'
                    # realname=`cat /usr/local/eistemp/eistempname$name`
                    techo --html --std $type $realname --info "$value$unit" --warn "$min$unit" --error "$max$unit"
                    mecho --html ""
                fi

                # Definition ping
                if [ "$type" == "ping" ]
                then
                    value=`ping -c $max $name 2>/dev/null | grep "packets" | sed 's/.* transmitted, //; s/received.*//'`
                    techo --html --std $type $name --info "$value" --warn "$min" --error "$max"
                    echo ""
                fi

                # Definition ping6
                if [ "$type" == "ping6" ]
                then
                    value=`ping6 -c $max $name 2>/dev/null | grep "received" | sed 's/.* transmitted, //; s/received.*//'`
                    techo --html --std $type $name --info "$value" --warn "$min" --error "$max"
                    echo ""
                fi

                # Definition loadavg
                if [ "$type" == "loadavg" ]
                then
                    value=`cut -d " " -f$name /proc/loadavg  | sed "s/\\.//; s/^0*//" 2>/dev/null`
                    case $name in
                        1) realname="1min";;
                        2) realname="5min";;
                        3) realname="10min";;
                    esac
                    techo --html --std $type $realname --info "$value %" --warn "$min %" --error "$max %"
                    echo ""
                fi

                # Definition lmsensors
                if [ "$type" == "lmsensors" ]
                then
                    value=`/usr/bin/sensors 2>/dev/null | grep "$name" | awk -F ":" '{ print $2 }' | awk '{ print $1 }' | sed s"/[+-]//" | sed s"/ (.*$//; s/ .*$//" | cut -d "." -f1 | sed s'/.C$//'`
                    techo --html --std $type $name --info "$value $unit" --warn "$min $unit" --error "$max $unit"
                    echo ""
                fi

                # Definition echoping
                if [ "$type" == "echoping" ]
                then
                    type="http"
                fi
                if [ "$type" == "http" ]
                then
                    value=`/usr/local/bin/echoping -t2 -h / $name 2>/dev/null | cut -c 1-7 2>/dev/null`
                    if  [ "$value" != "Elapsed" ]
                    then
                        result='Fail'
                    else
                        result='OK'
                    fi
                    techo --html --std $type $name --info "$result" --warn "-" --error "-"
                    echo ""
                fi

                # Definition pop3test
                if [ "$type" == "pop3" ]
                then
                    value=`( echo "quit" ) | telnet $name 110 | sed -n '4p' | cut -c-3 2>/dev/null`
                if  [ "$value" != "+OK" ]
                then
                    result='Fail'
                else
                    result='OK'
                fi
                techo --html --std $type $name --info "$result" --warn "-" --error "-"
                echo ""
                fi

                # Definition smtp neu
                if [ "$type" == "smtp" ]
                then
                    value=`/usr/local/bin/echoping -S $name 2>/dev/null | cut -c 1-7`
                    if  [ "$value" != "Elapsed" ]
                    then
                        result='Fail'
                    else
                        result='OK'
                    fi
                    techo --html --std $type $name --info "$result" --warn "-" --error "-"
                    echo ""
                fi

                # Definition ftptest
                if [ "$type" == "ftp" ]
                then
                    value=`( echo "QUIT" ) | netcat -i 1 $name 21 | sed -n '1p' | cut -c-3 2>/dev/null`
                    if  [ "$value" != "220" ]
                    then
                        result='Fail'
                    else
                        result='OK'
                    fi
                    techo --html --std $type $name --info "$result" --warn "-" --error "-"
                    echo ""
                fi

                # Definition CMD
                if [ "$type" == "cmd" ]
                then
                    value=`$runcmd 2>/dev/null`
                    techo --html --std $type $name --info "$value $unit" --warn "$min $unit" --error "$max $unit"
                    echo ""
                fi

                # Definition hddtemp
                if [ "$type" == "hddtemp" ]
                then
                    value=`hddtemp -n $name 2>/dev/null | sed s'/^.* drive is sleeping/sleep/'`
                    techo --html --std $type $name --info "$value $unit" --warn "$min $unit" --error "$max $unit"
                    echo ""
                fi

                # Definition ps
                if [ "$type" == "ps" ]
                then
                    value=`ps ax | grep "$name" | grep -v "grep" 2>/dev/null`
                    if [ "$value" != "" ]
                    then
                        value2="OK"
                    else
                        value2="FAIL"
                    fi
                    techo --html --std $type $name --info "$value2" --warn "$min" --error "$max"
                    echo ""
                fi

                # Definition df
                if [ "$type" == "df" ]
                then
                    value=`df -m | grep "$name" | awk '{ print $4 }' 2>/dev/null`
                    techo --html --std $type $name --info "$value MB" --warn "$min MB" --error "-"
                    echo ""
                fi

                # Definition https echoping
                if [ "$type" == "https" ]
                then
                    value=`/usr/local/bin/echoping -t2 -C -h / $name 2>/dev/null | cut -c 1-7` 
                    if  [ "$value" != "Elapsed" ]
                    then
                        result='Fail'
                    else
                        result='OK'
                    fi
                    techo --html --std $type $name --info "$result" --warn "-" --error "-"
                    echo ""
                fi

                # Definition apcups
                if [ "$type" == "apcups" ]
                then
                    value=`cat /etc/apcupsd/apcupsd.status 2>/dev/null | grep "^$name" | awk '{ print $3 }' | cut -d"." -f1`
                    techo --html --std $type $name --info "$value $unit" --warn "$min $unit" --error "$max $unit"
                    echo ""
                fi

                # SourceSchleife abschliessen
                idxs=`/usr/bin/expr $idxs + 1`
            done
            techo --html end
            mecho --html "---------------------------------------------------<br>"
        else
            mecho --html --warn "Monitoring-Group$idx Status: Inactive<br>"
            mecho --html "---------------------------------------------------<br>"
        fi

        # GruppenSchleife abschliessen
        idx=`/usr/bin/expr $idx + 1`
    done
else
    mecho --html "-----------------------------------------"
    mecho --html --error "Monitoring ist nicht aktiv!"
    mecho --html ""
fi

echo "<br><br><br>"

echo "<input type='button' value='Run monitoring.sh' onClick=\"self.location.href='$myname?runmonitoring'\">"

echo "</body>"
echo "</html>"
