#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/monitoring-update.sh  - parameter update script
#
# Creation:     27.11.2005  Stephan Sanders
# Last Update:  23.03.2018  Stephan Sanders
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=monitoring

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

#exec 2> /tmp/monitoring-update-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------

START_MONITORING='no'
MONITORING_CRON='*/15 * * * *'
MONITORING_FLAGCONTROL='yes'
MONITORING_GROUP_N='1'
MONITORING_GROUP_1_ACTIVE='no'
MONITORING_GROUP_1_MAIL='root@localhost'
MONITORING_GROUP_1_MAILSUBJECT=''
MONITORING_GROUP_1_YAPS=''
MONITORING_GROUP_1_CMD=''
MONITORING_GROUP_1_SOURCE_N='1'
MONITORING_GROUP_1_SOURCE_1_TYPE='eistemp'
MONITORING_GROUP_1_SOURCE_1_CMD=''
MONITORING_GROUP_1_SOURCE_1_NAME='1'
MONITORING_GROUP_1_SOURCE_1_UNIT='C'
MONITORING_GROUP_1_SOURCE_1_MIN=''
MONITORING_GROUP_1_SOURCE_1_MAX=''

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        # backup old configfile
        /var/install/bin/backup-file --quiet ${package_name}

        . /etc/config.d/${package_name}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2018-03-14" "Stephan Sanders"
    # -----------------------------------------------------------------------

    #------------------------------------------------------------------------
    printgroup "monitoring configuration"
    #------------------------------------------------------------------------

    printvar "START_MONITORING"
    printcomment        "Activate Monitoring? Use: yes or no"

    #-------------------------------------------------------------------------
    printgroup "Basics to install monitoring"
    #-------------------------------------------------------------------------

    printvar "MONITORING_CRON"
    printcomment        "Crontab to run Monitoring"

    printvar "MONITORING_FLAGCONTROL"
    printcomment        "Use: yes or no"
    printcomment        "yes: only report alarm if status changed (default)"
    printcomment        "no:  report every alarm"

    #-------------------------------------------------------------------------
    printcustomgroup "Group definitions" <<!EOC
    # You can define n-groups with individual m-sensors
    #
    # For every group you can select the receiver, the way of messaging
    # (mail, SMS or command) and the subject.
!EOC
    #-------------------------------------------------------------------------

    printvar "MONITORING_GROUP_N"
    printcomment        "Number of monitoring groups"

    idx=1
    while [ ${idx} -le ${MONITORING_GROUP_N} ]
    do
        printvar "MONITORING_GROUP_${idx}_ACTIVE"
        printcomment        "Is this group active? Use: yes or no"
        printvar "MONITORING_GROUP_${idx}_MAIL"
        printcomment        "Receiver for this group"
        printvar "MONITORING_GROUP_${idx}_MAILSUBJECT"
        printcomment        "Subject for this group"
        printvar "MONITORING_GROUP_${idx}_YAPS"
        printcomment        "Send SMS via YAPS too? Use: yes or no"
        printvar "MONITORING_GROUP_${idx}_CMD"
        printcomment        "Is this group active? Use: yes or no"
        printvar "MONITORING_GROUP_${idx}_SOURCE_N"
        printcomment        "Number of sources for this group"

        eval sourcelines='${MONITORING_GROUP_'${idx}'_SOURCE_N}'
        idx2=1
        while [ ${idx2} -le ${sourcelines} ]
        do
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_TYPE"
            printcomment        "Type of source (eg eistemp; smd; ping) see docu!"
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_CMD"
            printcomment        "For custom commands or scripts"
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_NAME"
            printcomment        "Name for this source"
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_UNIT"
            printcomment        "Unit for this source"
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_MIN"
            printcomment        "Minimum value"
            printvar "MONITORING_GROUP_${idx}_SOURCE_${idx2}_MAX"
            printcomment        "Maximum value"
            idx2=$((idx2 + 1))
        done
        idx=$((idx + 1))

    #-------------------------------------------------------------------------

    done

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

make_config_file /etc/default.d/${package_name}

# Update from old version
rename_old_variables

# Write new config file
make_config_file /etc/config.d/${package_name}

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
